==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebGridToolbarContentDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
var WebGridToolbarContentDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridToolbarContentDescriptionMetadata, _super);
    function WebGridToolbarContentDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridToolbarContentDescriptionMetadata.b = function (a) {
        if (WebGridToolbarContentDescriptionMetadata.a == null) {
            WebGridToolbarContentDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridToolbarContentDescriptionMetadata.c(WebGridToolbarContentDescriptionMetadata.a);
        }
        if (a.k(WebGridToolbarContentDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebGridToolbarContentDescriptionMetadata.a);
    };
    WebGridToolbarContentDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridToolbarContent");
        a.item("__tagNameWC", "String:igc-grid-toolbar-content");
        a.item("__manageCollectionInMarkup", "Boolean");
        a.item("Name", "String");
        WebGridToolbarContentDescriptionMetadata.e(a);
    };
    WebGridToolbarContentDescriptionMetadata.d = function (a) {
        WebGridToolbarContentDescriptionMetadata.b(a);
        a.ac("WebGridToolbarContent", WebGridToolbarContentDescriptionMetadata.a);
    };
    WebGridToolbarContentDescriptionMetadata.e = function (a) {
        a.item("__tagNameWCSubstitutable", "String:igc-grid-toolbar-actions,igc-grid-toolbar-title");
    };
    WebGridToolbarContentDescriptionMetadata.$t = markType(WebGridToolbarContentDescriptionMetadata, 'WebGridToolbarContentDescriptionMetadata');
    WebGridToolbarContentDescriptionMetadata.a = null;
    return WebGridToolbarContentDescriptionMetadata;
}(Base));
export { WebGridToolbarContentDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/WebGridToolbarContentDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
var WebGridToolbarContentDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridToolbarContentDescriptionMetadata, _super);
    function WebGridToolbarContentDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridToolbarContentDescriptionMetadata.b = function (a) {
        if (WebGridToolbarContentDescriptionMetadata.a == null) {
            WebGridToolbarContentDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridToolbarContentDescriptionMetadata.c(WebGridToolbarContentDescriptionMetadata.a);
        }
        if (a.k(WebGridToolbarContentDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebGridToolbarContentDescriptionMetadata.a);
    };
    WebGridToolbarContentDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridToolbarContent");
        a.item("__tagNameWC", "String:igc-grid-toolbar-content");
        a.item("__manageCollectionInMarkup", "Boolean");
        a.item("Name", "String");
        WebGridToolbarContentDescriptionMetadata.e(a);
    };
    WebGridToolbarContentDescriptionMetadata.d = function (a) {
        WebGridToolbarContentDescriptionMetadata.b(a);
        a.ad("WebGridToolbarContent", WebGridToolbarContentDescriptionMetadata.a);
    };
    WebGridToolbarContentDescriptionMetadata.e = function (a) {
        a.item("__tagNameWCSubstitutable", "String:igc-grid-toolbar-actions,igc-grid-toolbar-title");
    };
    WebGridToolbarContentDescriptionMetadata.$t = markType(WebGridToolbarContentDescriptionMetadata, 'WebGridToolbarContentDescriptionMetadata');
    WebGridToolbarContentDescriptionMetadata.a = null;
    return WebGridToolbarContentDescriptionMetadata;
}(Base));
export { WebGridToolbarContentDescriptionMetadata };
